#!/bin/sh
#
# (c) Copyright 2015 Basement Supercomputing
# Script to collect Limulus data
# 

#set -x

VERSION="1.0"
createfile()
{
# arguments, node, command, output file
echo "<html><body bgcolor=\"#FFFFFF\">" > $1/$3
echo "<pre>" >>$1/$3
 ssh $1  $2 >> $1/$3  2>&1
echo "</pre>" >>$1/$3
echo "</html></body>" >> $1/$3
}

createindexfile ()
{
# arguments node
LIST=`ls *.html`
echo "<html><body bgcolor=\"#FFFFFF\">" >index.html
echo "<H2>Machine: $1</H2>" >>index.html
echo "<H3>$DATE</H3>"  >>index.html
for I in $LIST
do
  J=`basename $I .html`
  echo "<a href=\"$I\">$J</a><br>"  >>index.html
done
echo "</html></body>" >> index.html
}

if [ ! $UID = "0" ] 
then 
	echo "Please run this script as root."
	exit 1
fi
HEADNAME=`hostname`
HEADNODE=`hostname -a`
# use dmidecode, strip off any messages before ID
MACHINEID=`dmidecode -s system-uuid|tail -n1`
NODELIST=`pdsh pwd|gawk -F: '{print $1}'|sort`
DATE=`date +%F`_`date +%R`
BASEDIR=/var/warewulf
echo -n "Collecting data for System: "
echo $HEADNAME-$MACHINEID
echo "Nodes:"
echo $NODELIST
cat <<EOF >/opt/etc/hdparm-disk.sh 
LIST=\`/sbin/fdisk -l 2> /dev/null|grep bytes|grep dev\/sd |gawk '{print \$2}'|gawk -F: '{print \$1}'\`
for DRIVE in \$LIST
do
/sbin/hdparm -i \$DRIVE
done
EOF

mkdir -p $BASEDIR/$HEADNAME-$MACHINEID/$DATE
cd  $BASEDIR/$HEADNAME-$MACHINEID/$DATE
# headnode specific 
mkdir -p $HEADNODE
createfile $HEADNODE  "echo $DATE" log-date.html
createfile $HEADNODE 'rpm -qa' rpm-qa.html
  if [ -x /usr/bin/wwsh ]; then
    createfile $HEADNODE 'wwsh vnfs list' warewulf-vnfs.html
    createfile $HEADNODE 'wwsh file list'  warewulf-file.html
    createfile $HEADNODE 'wwsh bootstrap list'  warewulf-bootstrap.html
  else
    createfile $HEADNODE 'echo "NOT A WAREWULF SYSTEM"' warewulf-vnfs.html
    createfile $HEADNODE 'echo "NOT A WAREWULF SYSTEM"'  warewulf-file.html
    createfile $HEADNODE 'echo "NOT A WAREWULF SYSTEM"'  warewulf-bootstrap.html
    echo "NOT A WAREWULF SYSTEM">>warewulf-provision.html
  fi
cd $HEADNODE
echo "<html><body bgcolor=\"#FFFFFF\">" >  warewulf-provision.html
echo "<pre>" >> warewulf-provision.html
for N in $NODELIST 
do
  if [ -x /usr/bin/wwsh ]; then
    wwsh provision print $N  >> warewulf-provision.html
  else
    echo "NOT A WAREWULF SYSTEM">>warewulf-provision.html
  fi
done
echo "</pre>" >>warewulf-provision.html
echo "</html></body>" >> warewulf-provision.html
cp -rp /etc/warewulf warewulf
cd ..



FULLLIST="$HEADNODE $NODELIST"
for NAME in $FULLLIST
do
  mkdir -p $NAME
  echo -n "Collecting data from: $NAME "
  echo -n "."
  createfile $NAME  /usr/sbin/dmidecode  dmidecode.html
  echo -n "."
  createfile $NAME  '/bin/uname -a'  uname.html
  echo -n "."
  createfile $NAME  'cat /proc/cpuinfo' cpuinfo.html
  echo -n "."
  createfile $NAME  lspci lspci.html
  echo -n "."
  createfile $NAME 'sh /opt/etc/hdparm-disk.sh' hdparm.html
  echo -n "."
  createfile $NAME 'cat /proc/partitions' partitions.html
  echo -n "."
  createfile $NAME '/bin/df -hlT'  df-hlT.html
  echo -n "."
  createfile $NAME  '/sbin/fdisk -l ' fdisk.html
  echo -n "."
  createfile $NAME  'cat /etc/fstab ' fstab.html
  echo -n "."
  createfile $NAME  'module avail'  modules-avail.html
  echo -n "."
  createfile $NAME  '/sbin/lsmod '  lsmod.html
  echo -n "."
  createfile $NAME  '/bin/dmesg '  dmesg.html
  echo -n "."
  createfile $NAME  '/sbin/ifconfig '  ifconfig.html
  echo -n "."
  createfile $NAME  '/usr/bin/free '  free.html
  echo -n "."
  createfile $NAME  'cat /etc/hosts'  etc-hosts.html
  echo -n "."
  createfile $NAME  ' cat /etc/ld.so.conf'  etc-ld.so.conf.html
  echo -n "."
  createfile $NAME  ' ulimit -a'  ulimit-a.html
  echo -n "."
  createfile $NAME  ' ls /etc/ld.so.conf.d'  etc-ld.so.conf.d.html
  echo ""  
  cd $NAME 
  createindexfile $NAME
  cd ..
done
# create master machine index file
echo "<html><body bgcolor=\"#FFFFFF\">" >index.html
echo "<H2>Machine ID: $MACHINEID</H2>" >>index.html
echo "<H3>Run Date: $DATE</H3>"  >>index.html
echo "<H3>Gather.sh Version: $VERSION</H3>"  >>index.html
echo "<ul>"  >>index.html
for NAME in $FULLLIST
do
echo "<li>Machine: <a href=\"$NAME/index.html\">$NAME</a></li> "  >>index.html
done
echo "</ul></body></html>"  >>index.html
# create master date index file
# This will allow multiple runs to be stored in the same tree
cd ..
DATELIST=`ls -d *-*-*_*|sort -r`
echo "<html><body bgcolor=\"#FFFFFF\">" >index.html
echo "<H2>Machine ID: $MACHINEID</H2>" >>index.html
echo "<H3>Most Recent Run Date: $DATE</H3>"  >>index.html
echo "<H3>Gather.sh Version: $VERSION</H3>"  >>index.html
echo "<ul>"  >>index.html
for NAME in $DATELIST
do
echo "<li>Run Date: <a href=\"$NAME/index.html\">$NAME</a></li> "  >>index.html
done
echo "</ul></body></html>"  >>index.html

#/bin/rm /opt/etc/hdparm-disk.sh 
cd $BASEDIR
tar czf $HEADNAME-$MACHINEID.tgz $HEADNAME-$MACHINEID/ 
echo "Please send a copy of:"
echo "   $BASEDIR/$HEADNAME-$MACHINEID.tgz  "
echo "to lregister@basement-supercomputing.com"
echo ""
echo "Finished"
exit
